<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Colorado";
    var qsoPartyUrl = "http://ppraa.org/coqp";
    var overlayUrl = "http://www.no5w.com/OverlayColoradoRev6.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "ada");
  countySelection.options[1] = new Option("Alamosa", "ala");
  countySelection.options[2] = new Option("Arapahoe", "ara");
  countySelection.options[3] = new Option("Archuleta", "arc");
  countySelection.options[4] = new Option("Baca", "bac");
  countySelection.options[5] = new Option("Bent", "ben");
  countySelection.options[6] = new Option("Boulder", "bou");
  countySelection.options[7] = new Option("Broomfield", "bro");
  countySelection.options[8] = new Option("Chaffee", "cha");
  countySelection.options[9] = new Option("Cheyenne", "che");
  countySelection.options[10] = new Option("ClearCreek", "clc");
  countySelection.options[11] = new Option("Conejos", "con");
  countySelection.options[12] = new Option("Costilla", "cos");
  countySelection.options[13] = new Option("Crowley", "cro");
  countySelection.options[14] = new Option("Custer", "cus");
  countySelection.options[15] = new Option("Delta", "del");
  countySelection.options[16] = new Option("Denver", "den");
  countySelection.options[17] = new Option("Dolores", "dol");
  countySelection.options[18] = new Option("Douglas", "dou");
  countySelection.options[19] = new Option("Eagle", "eag");
  countySelection.options[20] = new Option("Elbert", "elb");
  countySelection.options[21] = new Option("ElPaso", "elp");
  countySelection.options[22] = new Option("Fremont", "fre");
  countySelection.options[23] = new Option("Garfield", "gar");
  countySelection.options[24] = new Option("Gilpin", "gil");
  countySelection.options[25] = new Option("Grand", "gra");
  countySelection.options[26] = new Option("Gunnison", "gun");
  countySelection.options[27] = new Option("Hinsdale", "hin");
  countySelection.options[28] = new Option("Huerfano", "hue");
  countySelection.options[29] = new Option("Jackson", "jac");
  countySelection.options[30] = new Option("Jefferson", "jef");
  countySelection.options[31] = new Option("Kiowa", "kio");
  countySelection.options[32] = new Option("KitCarson", "kic");
  countySelection.options[33] = new Option("Lake", "lak");
  countySelection.options[34] = new Option("LaPlata", "lap");
  countySelection.options[35] = new Option("Larimer", "lar");
  countySelection.options[36] = new Option("LasAnimas", "laa");
  countySelection.options[37] = new Option("Lincoln", "lin");
  countySelection.options[38] = new Option("Logan", "log");
  countySelection.options[39] = new Option("Mesa", "mes");
  countySelection.options[40] = new Option("Mineral", "min");
  countySelection.options[41] = new Option("Moffat", "mof");
  countySelection.options[42] = new Option("Montezuma", "mon");
  countySelection.options[43] = new Option("Montrose", "mot");
  countySelection.options[44] = new Option("Morgan", "mor");
  countySelection.options[45] = new Option("Otero", "ote");
  countySelection.options[46] = new Option("Ouray", "our");
  countySelection.options[47] = new Option("Park", "par");
  countySelection.options[48] = new Option("Phillips", "phi");
  countySelection.options[49] = new Option("Pitkin", "pit");
  countySelection.options[50] = new Option("Prowers", "pro");
  countySelection.options[51] = new Option("Pueblo", "pue");
  countySelection.options[52] = new Option("RioBlanco", "rib");
  countySelection.options[53] = new Option("RioGrande", "rig");
  countySelection.options[54] = new Option("Routt", "rou");
  countySelection.options[55] = new Option("Saguache", "sag");
  countySelection.options[56] = new Option("SanJuan", "saj");
  countySelection.options[57] = new Option("SanMiguel", "sam");
  countySelection.options[58] = new Option("Sedgwick", "sed");
  countySelection.options[59] = new Option("Summit", "sum");
  countySelection.options[60] = new Option("Teller", "tel");
  countySelection.options[61] = new Option("Washington", "was");
  countySelection.options[62] = new Option("Weld", "wel");
  countySelection.options[63] = new Option("Yuma", "yum");
  addMarker(39.86930000, -104.38000000, "Adams", "ada");
  addMarker(37.55420000, -105.74600000, "Alamosa", "ala");
  addMarker(39.65220000, -104.38000000, "Arapahoe", "ara");
  addMarker(37.20810000, -106.97900000, "Archuleta", "arc");
  addMarker(37.31870000, -102.56400000, "Baca", "bac");
  addMarker(37.95550000, -103.07200000, "Bent", "ben");
  addMarker(40.08780000, -105.37400000, "Boulder", "bou");
  addMarker(39.96660000, -105.06300000, "Broomfield", "bro");
  addMarker(38.74000000, -106.23900000, "Chaffee", "cha");
  addMarker(38.82970000, -102.60900000, "Cheyenne", "che");
  addMarker(39.70840000, -105.66300000, "ClearCreek", "clc");
  addMarker(37.19870000, -106.19800000, "Conejos", "con");
  addMarker(37.32630000, -105.45100000, "Costilla", "cos");
  addMarker(38.31790000, -103.78000000, "Crowley", "cro");
  addMarker(38.07740000, -105.42300000, "Custer", "cus");
  addMarker(38.94290000, -107.94000000, "Delta", "del");
  addMarker(39.76430000, -104.85500000, "Denver", "den");
  addMarker(37.69010000, -108.45200000, "Dolores", "dol");
  addMarker(39.34810000, -104.99500000, "Douglas", "dou");
  addMarker(39.63740000, -106.64500000, "Eagle", "eag");
  addMarker(39.21650000, -104.18900000, "Elbert", "elb");
  addMarker(38.82470000, -104.56200000, "ElPaso", "elp");
  addMarker(38.47750000, -105.47700000, "Fremont", "fre");
  addMarker(39.72870000, -108.04200000, "Garfield", "gar");
  addMarker(39.84220000, -105.54900000, "Gilpin", "gil");
  addMarker(40.08520000, -106.14000000, "Grand", "gra");
  addMarker(38.70230000, -106.94000000, "Gunnison", "gun");
  addMarker(37.78500000, -107.29600000, "Hinsdale", "hin");
  addMarker(37.65410000, -104.92600000, "Huerfano", "hue");
  addMarker(40.66300000, -106.36200000, "Jackson", "jac");
  addMarker(39.52200000, -105.22400000, "Jefferson", "jef");
  addMarker(38.44040000, -102.77600000, "Kiowa", "kio");
  addMarker(39.30580000, -102.60500000, "KitCarson", "kic");
  addMarker(39.21850000, -106.36100000, "Lake", "lak");
  addMarker(37.31970000, -107.93100000, "LaPlata", "lap");
  addMarker(40.62810000, -105.56900000, "Larimer", "lar");
  addMarker(37.40510000, -104.11500000, "LasAnimas", "laa");
  addMarker(39.04150000, -103.60500000, "Lincoln", "lin");
  addMarker(40.71890000, -103.11600000, "Logan", "log");
  addMarker(38.93330000, -108.21900000, "Mesa", "mes");
  addMarker(37.68370000, -106.91900000, "Mineral", "min");
  addMarker(40.61160000, -108.18200000, "Moffat", "mof");
  addMarker(37.31960000, -108.50700000, "Montezuma", "mon");
  addMarker(38.41040000, -108.28300000, "Montrose", "mot");
  addMarker(40.26260000, -103.80700000, "Morgan", "mor");
  addMarker(37.95420000, -103.73000000, "Otero", "ote");
  addMarker(38.11240000, -107.82200000, "Ouray", "our");
  addMarker(39.13070000, -105.76900000, "Park", "par");
  addMarker(40.59420000, -102.35800000, "Phillips", "phi");
  addMarker(39.17200000, -106.94600000, "Pitkin", "pit");
  addMarker(37.95610000, -102.39500000, "Prowers", "pro");
  addMarker(38.12860000, -104.55200000, "Pueblo", "pue");
  addMarker(39.93780000, -108.04400000, "RioBlanco", "rib");
  addMarker(37.61730000, -106.37500000, "RioGrande", "rig");
  addMarker(40.46100000, -107.03400000, "Routt", "rou");
  addMarker(38.10300000, -106.21500000, "Saguache", "sag");
  addMarker(37.80230000, -107.71700000, "SanJuan", "saj");
  addMarker(37.96430000, -108.38900000, "SanMiguel", "sam");
  addMarker(40.87570000, -102.35200000, "Sedgwick", "sed");
  addMarker(39.64110000, -106.10800000, "Summit", "sum");
  addMarker(38.88870000, -105.13500000, "Teller", "tel");
  addMarker(40.00210000, -103.24400000, "Washington", "was");
  addMarker(40.50110000, -104.31500000, "Weld", "wel");
  addMarker(40.00390000, -102.42700000, "Yuma", "yum");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

